# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly

# Par of the data for Fig. S9 stems from Fig. 3c
data_3c=as.data.frame(read_excel('Fig_3c.xlsx',sheet=2))

# Data formatting
data_3c$Gel=as.factor(data_3c$Gel)

data_3c$Run=as.factor(data_3c$Run)

# Keep only minimal required information for assembly with hESC data
data_3c=data_3c[data_3c$Coating %in% c("Laminin","No_protein_control"),c("Run","Coating","neurite_length", "neurites_per_DAPI")]

data_3c$Cell_type = "LUHMES"

# The hESC data is supplied separately in Supplementary_Fig_S9.xlsx, read this here. 
neurite_per_DAPI_hESC=as.data.frame(read_excel('Supplementary_Fig_S9.xlsx',sheet=2,range="I3:I7"))

neurite_per_DAPI_hESC=neurite_per_DAPI_hESC[!is.na(neurite_per_DAPI_hESC[,"Neurite per cell per gel"]),]

# The ranges are not contiguous
neurite_length_hESC=as.data.frame(read_excel('Supplementary_Fig_S9.xlsx',sheet=2,range="M3:M7"))

neurite_length_hESC=neurite_length_hESC[!is.na(neurite_length_hESC[,"Neurite length"]),]

# Assemble the data. The runs for hESC should be counted differently, these are fundamentally different experiments
data_S9 = data.frame(Run=max(as.numeric(as.character(data_3c$Run)))+1,Coating="Laminin",neurite_length=neurite_length_hESC,neurites_per_DAPI=neurite_per_DAPI_hESC,Cell_type="HS420")

data_S9=rbind(data_S9,data_3c)

data_S9$Run=as.factor(data_S9$Run)

data_S9$Condition = as.factor(paste(data_S9$Coating, data_S9$Cell_type))

# Clustering analysis along the biological replicates (column "Run"), again, the hESC run is considered apart from the Luhmes runs
data_S9$group=data_S9$Run


# Subtraction of the main effects (associated with coating and cell type) to recover the residual errors for correlation analysis (https://www.jstor.org/stable/2683375)
per_run = aggregate(neurites_per_DAPI ~ Run + Condition,data_S9, FUN=mean)

per_Condition =aggregate(neurites_per_DAPI ~  Condition,per_run, FUN=mean)

data_S9$neurites_per_DAPI_Condition_effect_subtracted = data_S9$neurites_per_DAPI-per_Condition$neurites_per_DAPI[match(data_S9$Condition,per_Condition$Condition)]


# Moulton factor for the neurite per DAPI evaluation
# The biological replicates being entirely distinct between the hESC and the LUHMES, the maximum estimation of the Moulton factor applies directly. See cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090

moulton_factor(data_S9$neurites_per_DAPI_Condition_effect_subtracted, data_S9$group)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square


per_run = aggregate(neurite_length ~ Run + Condition,data_S9, FUN=mean)

per_Condition =aggregate(neurite_length ~  Condition,per_run, FUN=mean)

data_S9$neurite_length_Condition_effect_subtracted = data_S9$neurite_length-per_Condition$neurite_length[match(data_S9$Condition,per_Condition$Condition)]

# Moulton factor for the neurite length
# as above, the worst-case assumption applies here due to entirely distinct runs for the hESC and LUHMES

moulton_factor(data_S9$neurite_length_Condition_effect_subtracted, data_S9$group)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square

# We cannot fully correct the problem of intraclass correlation by aggregation to biological replicates, otherwise, there is only point experiment on the hESC side
# We therefore aggregate only the more numerous Luhmes data
# The statistical question is then whether the hESC results from the one experiment analyzed are compatible with a typical Luhmes experimental run. It gives an indication that is 
# stronger than if only a single Luhmes vs. hESC experiment were conducted, but it is not as strong as comparing several Luhmes to several hESC experiments.

data_S9_non_aggregated = data_S9[data_S9$Cell_type=="HS420",c("Run","Condition","neurites_per_DAPI_Condition_effect_subtracted","neurite_length_Condition_effect_subtracted")]

data_S9_assembled =rbind(data_S9_non_aggregated,data.frame(Run=per_run$Run,Condition=per_run$Condition,neurites_per_DAPI_Condition_effect_subtracted=0,neurite_length_Condition_effect_subtracted=0))

# The aggregation on the LUHMES side is enough to deal with the problem of intraclass correlation
moulton_factor(data_S9_assembled$neurite_length_Condition_effect_subtracted, data_S9_assembled$Run)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square



